==> linux_tutorial_nabla-0.1.0.tar.gz: linux_tutorial_nabla-0.1.0/README.md <==
# Linux Tutorial Nabla

Welcome to the Nabla Linux Tutorial! This project provides an interactive terminal-based tutorial for learning basic Linux commands and navigation. The tutorial is designed to help users understand and practice essential Linux commands in a simulated terminal environment.

## Table of Contents

- [Features](#features)
- [Installation](#installation)
- [Usage](#usage)
- [Tutorials](#tutorials)
- [Contributing](#contributing)
- [License](#license)
- [Authors](#authors)

## Features

- Interactive terminal-based tutorials
- Step-by-step guidance for learning Linux commands
- Custom commands for navigating the tutorial
- Progress tracking and completion status for each tutorial

## Installation

To install the project, follow these steps:

1. Clone the repository:
    ```sh
    git clone https://github.com/yourusername/linux_tutorial_nabla.git
    cd linux_tutorial_nabla
    ```

2. Install dependencies using PDM:
    ```sh
    pdm install
    ```

## Usage

To start the tutorial, run the following command:
```sh
python -m linux_tutorial_nabla
```

You will be greeted with a welcome message and instructions on how to use the tutorial. You can run any command you want, and the tutorial will help you understand it.

## Tutorials
The project includes several tutorials to help you learn different aspects of Linux. Here are some of the available tutorials:

- Navigation: Learn how to navigate the terminal using commands like pwd and cd.
- File Basics: Learn basic file operations such as creating, viewing, and describing files.

To start a tutorial, type start <tutorial name> and press enter. For example:

## Contributing
We welcome contributions to improve the tutorials and add new features. To contribute, follow these steps:

1. Fork the repository.
2. Create a new branch for your feature or bugfix.
3. Make your changes and commit them with a descriptive message.
4. Push your changes to your fork.
5. Create a pull request to the main repository.

Please ensure your code follows the project's coding standards and includes appropriate tests.

## License
This project is licensed under the MIT License. See the LICENSE file for details.

## Authors
- [Martin Sundal Aspås](https://github.com/MartinSA04)

Happy learning!

==> linux_tutorial_nabla-0.1.2.tar.gz: linux_tutorial_nabla-0.1.2/README.md <==
# Linux Tutorial Nabla

Welcome to the Nabla Linux Tutorial! This project provides an interactive terminal-based tutorial for learning basic Linux commands and navigation. The tutorial is designed to help users understand and practice essential Linux commands in a simulated terminal environment.

## Table of Contents

- [Features](#features)
- [Installation](#installation)
- [Usage](#usage)
- [Tutorials](#tutorials)
- [Contributing](#contributing)
- [License](#license)
- [Authors](#authors)

## Features

- Interactive terminal-based tutorials
- Step-by-step guidance for learning Linux commands
- Custom commands for navigating the tutorial
- Progress tracking and completion status for each tutorial

## Installation

To install the project, follow these steps:
1. Install the project using pip:
    ```sh
    pip install linux-tutorial-nabla
    ```    


Alternatively install from source:

1. Clone the repository:
    ```sh
    git clone https://github.com/yourusername/linux_tutorial_nabla.git
    cd linux_tutorial_nabla
    ```

2. Install dependencies using PDM:
    ```sh
    pdm install
    ```

## Usage

To start the tutorial, run the following command:
```sh
linux_tutorial_nabla
```

You will be greeted with a welcome message and instructions on how to use the tutorial. You can run any command you want, and the tutorial will help you understand it.

## Tutorials
The project includes several tutorials to help you learn different aspects of Linux. Here are some of the available tutorials:

- Navigation: Learn how to navigate the terminal using commands like pwd and cd.
- File Basics: Learn basic file operations such as creating, viewing, and describing files.

To start a tutorial, type start <tutorial name> and press enter. For example:

## Contributing
We welcome contributions to improve the tutorials and add new features. To contribute, follow these steps:

1. Fork the repository.
2. Create a new branch for your feature or bugfix.
3. Make your changes and commit them with a descriptive message.
4. Push your changes to your fork.
5. Create a pull request to the main repository.

Please ensure your code follows the project's coding standards and includes appropriate tests.

## License
This project is licensed under the MIT License. See the LICENSE file for details.

## Authors
- [Martin Sundal Aspås](https://github.com/MartinSA04)

Happy learning!
